@@ -2,10 +2,12 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
+import json
 from builtins import str as text
 
 from future.utils import python_2_unicode_compatible, iteritems, string_types
 
+from pandagg._decorators import Substitution
 from pandagg.node.query._parameter_clause import ParentParameterClause
 from pandagg.node.query.abstract import QueryClause, LeafQueryClause
 from pandagg.node.query.compound import CompoundClause, Bool as BoolNode
@@ -18,6 +20,32 @@ ADD = "add"
 REPLACE = "replace"
 REPLACE_ALL = "replace_all"
 
+sub_insertion = Substitution(
+    insertion_doc="""
+    * *parent* (``str``) --
+      named query clause under which the inserted clauses should be placed.
+
+    * *parent_param* (``str`` optional parameter when using *parent* param) --
+      parameter under which inserted clauses will be placed. For instance if *parent* clause is a boolean, can be
+      'must', 'filter', 'should', 'must_not'.
+
+    * *child* (``str``) --
+      named query clause above which the inserted clauses should be placed.
+
+    * *child_param* (``str`` optional parameter when using *parent* param) --
+      parameter of inserted boolean clause under which child clauses will be placed. For instance if inserted clause
+      is a boolean, can be 'must', 'filter', 'should', 'must_not'.
+
+    * *mode* (``str`` one of 'add', 'replace', 'replace_all') --
+      merging strategy when inserting clauses on a existing compound clause.
+
+      - 'add' (default) : adds new clauses keeping initial ones
+      - 'replace' : for each parameter (for instance in 'bool' case : 'filter', 'must', 'must_not', 'should'),
+        replace existing clauses under this parameter, by new ones only if declared in inserted compound query
+      - 'replace_all' : existing compound clause is completely replaced by the new one
+"""
+)
+
 
 @python_2_unicode_compatible
 class Query(Tree):
@@ -166,7 +194,10 @@ class Query(Tree):
         return None
 
     def to_dict(self, from_=None, with_name=True):
-        """Return None if no query clause.
+        """Serialize query as native dict.
+        :param from\_: optional,
+        :param with_name: optional
+        :return:
         """
         if self.root is None:
             return None
@@ -198,7 +229,37 @@ class Query(Tree):
             return {node.KEY: serialized_children}
         return {node.KEY: serialized_children[0]}
 
+    @sub_insertion
     def query(self, *args, **kwargs):
+        r"""Insert new clause(s) in current query.
+
+        Inserted clause can accepts following syntaxes.
+
+        Given an empty query:
+
+        >>> from pandagg.query import Query
+        >>> q = Query()
+
+        flat syntax: clause type, followed by query clause body as keyword arguments:
+
+        >>> q.query('term', some_field=23)
+        {'term': {'some_field': 23}}
+
+        from regular Elasticsearch dict query:
+
+        >>> q.query({'term': {'some_field': 23}})
+        {'term': {'some_field': 23}}
+
+        using pandagg DSL:
+
+        >>> from pandagg.query import Term
+        >>> q.query(Term(field=23))
+        {'term': {'some_field': 23}}
+
+        :Keyword Arguments:
+        %(insertion_doc)s
+
+        """
         mode = kwargs.pop("mode", ADD)
         parent = kwargs.pop("parent", None)
         parent_param = kwargs.pop("parent_param", None)
@@ -506,13 +567,13 @@ class Query(Tree):
             )
             if not existing_param:
                 self.insert(
-                    item=new_compound.subtree(param_node.identifier), parent_id=name,
+                    item=new_compound.subtree(param_node.identifier), parent_id=name
                 )
                 continue
             if mode == REPLACE:
                 self.drop_node(existing_param.identifier)
                 self.insert(
-                    item=new_compound.subtree(param_node.identifier), parent_id=name,
+                    item=new_compound.subtree(param_node.identifier), parent_id=name
                 )
                 continue
             if mode == ADD:
@@ -532,7 +593,15 @@ class Query(Tree):
         return self
 
     def __str__(self):
-        return "<Query>\n%s" % text(self.show())
+        return json.dumps(self.to_dict(), indent=2)
+
+    def show(self, *args, **kwargs):
+        stdout = kwargs.pop("stdout", True)
+
+        result = "<Query>\n%s" % text(super(Query, self).show(*args, **kwargs))
+        if not stdout:
+            return result
+        print(result)
 
 
 class Leaf(Query):
