@@ -5,8 +5,9 @@
 #                                   IMPORTS
 # =============================================================================
 
+from __future__ import unicode_literals
 from unittest import TestCase
-from lighttree.exceptions import MultipleRootError, NotFoundNodeError
+from lighttree.exceptions import NotFoundNodeError
 from mock import patch
 
 from pandagg.tree.aggs.aggs import Aggs
@@ -89,6 +90,13 @@ class AggTestCase(TestCase):
         )
         for a in (agg1, agg2, agg3, agg4, agg5):
             self.assertEqual(a.to_dict(), expected)
+            self.assertEqual(
+                a.show(stdout=False),
+                """<Aggregations>
+genres                                                <terms, field="genres", size=3>
+└── movie_decade               <date_histogram, field="year", fixed_interval="3650d">
+""",
+            )
 
     def test_add_node_with_mapping(self):
         with_mapping = Aggs(mapping=MAPPING, nested_autocorrect=True)
@@ -103,8 +111,7 @@ class AggTestCase(TestCase):
         # try to add field aggregation on non-existing field will fail
         with self.assertRaises(AbsentMappingFieldError):
             with_mapping.aggs(
-                Terms("imaginary_agg", field="imaginary_field"),
-                insert_below="workflow",
+                Terms("imaginary_agg", field="imaginary_field"), insert_below="workflow"
             )
         self.assertEqual(len(with_mapping.list()), 1)
 
@@ -141,6 +148,14 @@ class AggTestCase(TestCase):
                 }
             },
         )
+        self.assertEqual(
+            with_mapping.show(stdout=False),
+            """<Aggregations>
+workflow                                                    <terms, field="workflow">
+└── nested_below_workflow                              <nested, path="local_metrics">
+    └── local_f1_score         <avg, field="local_metrics.performance.test.f1_score">
+""",
+        )
         self.assertIn("nested_below_workflow", with_mapping)
         nested_node = with_mapping.get("nested_below_workflow")
         self.assertEqual(nested_node.KEY, "nested")
@@ -354,7 +369,7 @@ class AggTestCase(TestCase):
                         "interval": "1w",
                     }
                 }
-            },
+            }
         )
         self.assertEqual({n.identifier for n in initial_agg_1.list()}, {"week"})
 
@@ -529,7 +544,7 @@ class AggTestCase(TestCase):
                 "one": {
                     "terms": {"field": "terms_one"},
                     "aggs": {"two": {"terms": {"field": "terms_two"}}},
-                },
+                }
             },
         )
 
@@ -691,7 +706,7 @@ class AggTestCase(TestCase):
                 "two": {
                     "terms": {"field": "terms_two"},
                     "aggs": {"one": {"terms": {"field": "terms_one"}}},
-                },
+                }
             },
         )
 
@@ -707,7 +722,7 @@ class AggTestCase(TestCase):
                 "one": {
                     "terms": {"field": "terms_one"},
                     "aggs": {"two": {"terms": {"field": "terms_two"}}},
-                },
+                }
             },
         )
 
@@ -1034,3 +1049,40 @@ class AggTestCase(TestCase):
         )
         agg2 = Aggs(node_hierarchy_2, mapping=MAPPING, nested_autocorrect=True)
         self.assertEqual(agg2.deepest_linear_bucket_agg, "week")
+
+    def test_groupby_pointer(self):
+        a = (
+            Aggs()
+            .groupby("A", "terms", field="a")
+            .groupby("B", "date_histogram", fixed_interval="1d", field="b")
+        )
+
+        self.assertEqual(a._groupby_ptr, "B")
+
+        a1 = a.aggs("C1", "terms", field="c1").aggs("C2", "terms", field="c2")
+        self.assertEqual(
+            a1.show(stdout=False),
+            """<Aggregations>
+A                                                                  <terms, field="a">
+└── B                                <date_histogram, field="b", fixed_interval="1d">
+    ├── C1                                                        <terms, field="c1">
+    └── C2                                                        <terms, field="c2">
+""",
+        )
+        self.assertEqual(
+            a1.to_dict(),
+            {
+                "A": {
+                    "aggs": {
+                        "B": {
+                            "aggs": {
+                                "C1": {"terms": {"field": "c1"}},
+                                "C2": {"terms": {"field": "c2"}},
+                            },
+                            "date_histogram": {"field": "b", "fixed_interval": "1d"},
+                        }
+                    },
+                    "terms": {"field": "a"},
+                }
+            },
+        )
